/* tslint:disable:max-line-length */
import { TestBed } from '@angular/core/testing';
import { AppComponent } from './app.component';
import {DataSourceService} from './services/data-source.service';
import {MatDialog} from '@angular/material/dialog';
import {of} from 'rxjs';
import {HttpClientTestingModule} from '@angular/common/http/testing';
import {UserContextService} from './services/user-context.service';
import {MatMenuModule} from '@angular/material/menu';
import {MatIconModule} from '@angular/material/icon';
import {CprSearchComponent} from './cpr-search/cpr-search.component';
import {NavigationBarComponent} from './navigationbar/navigationbar.component';
import {FeedbackButtonComponent} from './feedback-button/feedback-button.component';
import {Router, RouterModule} from '@angular/router';
import {DataCardService} from 'facade-api';
import {appRoutes} from './modules/routing.module';
import {FormsModule} from '@angular/forms';

describe('AppComponent', () => {

  beforeEach(async () => {
    const dataSourceService = {
      dummyDataCards$: of([1, 2, 3]),
      isLoading$: of(false)
    };
    const userContextService = {
      selectedRole$: of({authorizationCode: 'LK34Q', educationCode: '9495', educationType: 'Bandagist'}),
      userContext$: of({commonName: 'Lars Larsen', organizationName: 'Company A/S', eligibleRoles: [{authorizationCode: 'J0184', educationCode: '7170', educationType: 'Læge'}, {authorizationCode: 'LK34Q', educationCode: '9495', educationType: 'Bandagist'}]}),
      eligibleRoles$: of({authorizationCode: 'LK34Q', educationCode: '9495', educationType: 'Bandagist'})
    };
    await TestBed.configureTestingModule({
      declarations: [ AppComponent, CprSearchComponent, NavigationBarComponent, FeedbackButtonComponent ],
      imports: [HttpClientTestingModule, MatMenuModule, MatIconModule, RouterModule.forRoot(appRoutes), FormsModule],
      providers: [
        {provide: DataCardService, useValue: {}},
        {provide: DataSourceService, useValue: dataSourceService},
        {provide: MatDialog, useValue: {}},
        {provide: UserContextService, useValue: userContextService}
      ]
    })
      .compileComponents();
  });

  it('should create the app', () => {
    const fixture = TestBed.createComponent(AppComponent);
    const app = fixture.componentInstance;
    expect(app).toBeTruthy();
  });

  it(`should have as title 'maternaty-web'`, () => {
    const fixture = TestBed.createComponent(AppComponent);
    const app = fixture.componentInstance;
    expect(app.title).toEqual('eGraviditet');
  });

  it('should render title', () => {
    const fixture = TestBed.createComponent(AppComponent);
    fixture.detectChanges();
    const compiled = fixture.nativeElement;
    expect(compiled.querySelector('.patientContext > .patientName').textContent).toContain('Dame Kvindesen');
  });
});
