import {BrowserModule} from '@angular/platform-browser';
import {LOCALE_ID, NgModule} from '@angular/core';
import {AppComponent} from './app.component';
import {HTTP_INTERCEPTORS, HttpClientModule} from '@angular/common/http';
import {environment} from '../environments/environment';
import {DataCardComponent} from './data-card/data-card.component';
import {ApiModule, BASE_PATH, DataCardService} from 'facade-api';
import {HttpMockRequestInterceptor} from '../utils/mock.interceptor';
import {HttpRequestInterceptor} from '../utils/interceptor';
import {AngularMaterialModule} from './modules/angular-material.module';
import {NavigationBarComponent} from './navigationbar/navigationbar.component';
import {RoutingModule} from './modules/routing.module';
import {ActivitiesComponent} from './activities/activities.component';
import {MeasurementsScreeningsComponent} from './measurements/measurements-screenings/measurements-screenings.component';
import {MeasurementsScansComponent} from './measurements/measurements-scans/measurements-scans.component';
import {MeasurementsSummaryComponent} from './measurements/measurements-summary/measurements-summary.component';
import {MeasurementsTabComponent} from './measurements/measurements-tab/measurements-tab.component';
import {DialogComponent} from './modals/dialog/dialog.component';
import {BrowserAnimationsModule} from '@angular/platform-browser/animations';
import {LoadingComponent} from './modals/loading/loading.component';
import {registerLocaleData} from '@angular/common';
import {LocalizationPipe} from './activities/localize';
import {MeasurementsMidwifeComponent} from './measurements/measurements-midwife/measurements-midwife.component';
import {FeedbackButtonComponent} from './feedback-button/feedback-button.component';
import {FeedbackComponent} from './feedback/feedback.component';
import {FormsModule, ReactiveFormsModule} from '@angular/forms';
import {ActivityCardComponent} from './activities/activity-card/activity-card.component';
import {DataFieldComponent} from './activities/data-field/data-field.component';
import localeDa from '@angular/common/locales/da';
import {CprSearchComponent} from './cpr-search/cpr-search.component';
import {NgxMaskModule} from 'ngx-mask';
import {NoActivePathwayComponent} from './data-card/no-active-pathway/no-active-pathway.component';
import {MatIconModule} from '@angular/material/icon';
import { ModalComponent } from './modals/modal/modal.component';
import { ActivityModalComponent } from './activities/activity-modal/activity-modal.component';
import { FetusRelatedMeasurementsComponent } from './activities/activity-card/fetus-related-measurements/fetus-related-measurements.component';
// tslint:disable-next-line:max-line-length
import {RoleSelectorComponent} from './role-selector/role-selector.component';
import {MatMenuModule} from '@angular/material/menu';
import {MatTooltipModule} from '@angular/material/tooltip';
import { TooltipDirective } from './tooltip/tooltip.directive';
import {TabsComponent} from './tabs/tabs.component';
import {PregnancyComponent} from './pregnancy/pregnancy.component';
import {GeneralInformationBarComponent} from './general-information-bar/general-information-bar.component';
import {GestationAgePipe} from './general-information-bar/gestation-age.pipe';
import {PatientInformationComponent} from './patient-information/patient-information.component';
import {MatCardModule} from '@angular/material/card';
import {CardComponent} from './card/card.component';
import {InputComponent} from './input/input.component';
import {RadioGroupWrapperComponent} from './radio-group/radio-group-wrapper.component';
import {OptionalDatePipe} from './patient-information/optional-date.pipe';
import {NamePipe} from './patient-information/name.pipe';
import {EditPlanModalComponent} from './activities/edit-plan-modal/edit-plan-modal.component';
import {MatCheckboxModule} from '@angular/material/checkbox';
import {WeekNumberPipe} from './pipes/week-number.pipe';

registerLocaleData(localeDa);

@NgModule({
  declarations: [
    AppComponent,
    DataCardComponent,
    NavigationBarComponent,
    ActivitiesComponent,
    DialogComponent,
    LoadingComponent,
    CprSearchComponent,
    NoActivePathwayComponent,
    MeasurementsMidwifeComponent,
    MeasurementsTabComponent,
    MeasurementsScreeningsComponent,
    MeasurementsScansComponent,
    MeasurementsSummaryComponent,
    FeedbackButtonComponent,
    FeedbackComponent,
    LocalizationPipe,
    ActivityCardComponent,
    DataFieldComponent,
    ModalComponent,
    ActivityModalComponent,
    FetusRelatedMeasurementsComponent,
    RoleSelectorComponent,
    EditPlanModalComponent,
    TabsComponent,
    PregnancyComponent,
    GeneralInformationBarComponent,
    GestationAgePipe,
    WeekNumberPipe,
    TooltipDirective,
    PatientInformationComponent,
    CardComponent,
    InputComponent,
    RadioGroupWrapperComponent,
    OptionalDatePipe,
    NamePipe
  ],
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    HttpClientModule,
    ApiModule,
    AngularMaterialModule,
    RoutingModule,
    MatIconModule,
    MatCardModule,
    FormsModule,
    ReactiveFormsModule,
    NgxMaskModule.forRoot(),
    MatCheckboxModule,
    MatMenuModule,
    MatTooltipModule
  ],
  providers: [
    DataCardService,
    { provide: LOCALE_ID, useValue: 'da' },
    { provide: BASE_PATH, useValue: environment.base_path + '/api' },
    {
      provide: HTTP_INTERCEPTORS,
      useClass: environment.mock ? HttpMockRequestInterceptor : HttpRequestInterceptor,
      multi: true
    }
  ],
  bootstrap: [AppComponent]
})
export class AppModule {
  constructor() {

    console.log('Environment: ' + JSON.stringify(environment));
  }
}
