import { ComponentFixture, TestBed } from '@angular/core/testing';

import { InputComponent } from './input.component';
import {AngularMaterialModule} from '../modules/angular-material.module';
import {FormsModule} from '@angular/forms';
import {NoopAnimationsModule} from '@angular/platform-browser/animations';

describe('InputComponent', () => {
  let component: InputComponent;
  let fixture: ComponentFixture<InputComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [ InputComponent ],
      imports: [AngularMaterialModule, FormsModule, NoopAnimationsModule]
    })
    .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(InputComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('detects mouse hover events', (done) => {
    fixture.whenStable().then(() => {
      const element = fixture.elementRef.nativeElement;
      element.dispatchEvent(new Event('mouseenter'));
      fixture.detectChanges();
      expect(component.hover).toBeTrue();

      element.dispatchEvent(new Event('mouseleave'));
      fixture.detectChanges();
      expect(component.hover).toBeFalse();
      done();
    });
  });

  it('registers as touched on blur', (done) => {
    let touched = false;
    component.registerOnTouched(() => touched = true);
    fixture.whenStable().then(() => {
      const element = fixture.elementRef.nativeElement;
      element.dispatchEvent(new Event('blur'));
      fixture.detectChanges();
      expect(touched).toBeTrue();
      done();
    });
  });

  it('updates inner value when ngModel is updated on the outside', () => {
    component.writeValue('tis but a test');
    expect(component.innerModel).toEqual('tis but a test');
  });
});
