import {ComponentFixture, fakeAsync, TestBed, tick} from '@angular/core/testing';

import {PatientInformationComponent} from './patient-information.component';
import {of} from 'rxjs';
import {DataSourceService} from '../services/data-source.service';
import {Component, Input} from '@angular/core';
import {delay} from 'rxjs/operators';
import {FormsModule} from '@angular/forms';
import {AngularMaterialModule} from '../modules/angular-material.module';
import {CardComponent} from '../card/card.component';
import {NamePipe} from './name.pipe';
import {OptionalDatePipe} from './optional-date.pipe';
import {MatCheckboxModule} from '@angular/material/checkbox';
import {MatMenuModule} from '@angular/material/menu';
import {MatIconModule} from '@angular/material/icon';

@Component({
  selector: 'app-radio-group-wrapper',
  template: '<ng-content></ng-content>'
})
class MockGroupWrapperComponent {}

@Component({
  selector: 'app-input',
  template: '<p></p>'
})
class MockInputComponent {
  @Input() ngModel = '';
}

@Component({
  selector: 'app-general-information-bar',
  template: '<p>information-bar</p>'
})
class MockGeneralInformationBarComponent {}


describe('PatientInformationComponent', () => {
  let component: PatientInformationComponent;
  let fixture: ComponentFixture<PatientInformationComponent>;

  beforeEach(async () => {
    const dataSourceStub = {
      updateDataCard: () => of({}).pipe(
        delay(100)
      ),
      refresh: () => {},
      dummyDataCards$: of([{
        identifier: '1',
        episodeOfCareIdentifier: '2',
        recordTarget: {
          identifier: '1008821234',
          name: {
            firstNames: ['Peter'],
            middleNames: [],
            lastName: 'Parker'
          }
        },
        socialHistorySection: {
          partner: {}
        },
        expectedDateOfDeliverySection: {
          expectedDateOfDeliveryFromLastPeriod: {}
        }
      }])
    };

    await TestBed.configureTestingModule({
      declarations: [
        PatientInformationComponent,
        MockGroupWrapperComponent,
        MockGeneralInformationBarComponent,
        NamePipe,
        OptionalDatePipe,
        MockInputComponent,
        CardComponent
      ],
      imports: [AngularMaterialModule, FormsModule, MatCheckboxModule,
        MatMenuModule, MatIconModule],
      providers: [
        {provide: DataSourceService, useValue: dataSourceStub}
      ]
    })
    .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(PatientInformationComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
    expect((component as unknown as {identifier: string}).identifier).toEqual('2');
  });

  it('disables save button while saving', fakeAsync(() => {
    expect(component.disableSaveButton).toBeFalse();
    component.save();
    expect(component.disableSaveButton).toBeTrue();
    tick(200);
    expect(component.disableSaveButton).toBeFalse();
  }));
});
