import {Component, OnDestroy, OnInit} from '@angular/core';
import {DataSourceService} from '../services/data-source.service';
import {Subscription} from 'rxjs';
import {DataCard, DataCardRequest, Uuidv4} from 'facade-api';
import {FormControl, FormGroup, Validators} from '@angular/forms';

@Component({
  selector: 'app-patient-information',
  templateUrl: './patient-information.component.html',
  styleUrls: ['./patient-information.component.scss']
})
export class PatientInformationComponent implements OnInit, OnDestroy {
  public dataCard: DataCard|undefined;
  private identifier: Uuidv4 = '';
  private subscription: Subscription|undefined;
  public form: FormGroup | undefined;
  public disableSaveButton = false;

  constructor(private dataSourceService: DataSourceService) { }

  ngOnInit(): void {
    this.subscription = this.dataSourceService.dummyDataCards$
      .subscribe((dataCards) => {
        const {identifier, episodeOfCareIdentifier, ...dataCard} = dataCards[0];
        this.identifier = episodeOfCareIdentifier || '';
        this.dataCard = dataCard;
      });

    this.form = new FormGroup({
      maritalStatus: new FormControl(null, Validators.required),
    });
  }

  ngOnDestroy(): void {
    this.subscription?.unsubscribe();
  }

  public save(): void {
    this.disableSaveButton = true;
    this.dataSourceService.updateDataCard(this.identifier, this.dataCard as DataCardRequest)
      .subscribe(() => {
        this.disableSaveButton = false;
        this.dataSourceService.refresh();
      });
  }
}
