import { TooltipDirective } from './tooltip.directive';
import {ComponentFixture, fakeAsync, TestBed, tick} from '@angular/core/testing';
import {Component, NO_ERRORS_SCHEMA} from '@angular/core';
import {By} from '@angular/platform-browser';
import {DocumentService} from '../services/document.service';
import {WindowService} from '../services/window.service';

@Component({
  selector: 'app-test-component',
  template: '<div id="testContainer" style="width: 100px; height: 100px;" appTooltip="Hello World"></div>'
})
class TestComponent {}

describe('TooltipDirective', () => {
  let fixture: ComponentFixture<TestComponent>;
  beforeEach(() => {
    fixture = TestBed.configureTestingModule({
      declarations: [ TestComponent, TooltipDirective ],
      schemas:      [ NO_ERRORS_SCHEMA ],
      providers: [
        DocumentService,
        WindowService
      ]
    })
      .createComponent(TestComponent);
    fixture.detectChanges(); // initial binding
  });

  it('have a tooltip on mouseover',  fakeAsync( () => {
    const container: any = fixture.debugElement.query(By.css('#testContainer'));
    let tooltip = fixture.debugElement.query(By.css('.ng-tooltip'));
    expect(tooltip).toBeNull();
    container.triggerEventHandler('mouseenter', {});
    fixture.detectChanges();
    tick(100);
    tooltip = fixture.debugElement.query(By.css('.ng-tooltip'));
    expect(tooltip.nativeElement.innerText).toEqual('Hello World');
  }));

  it('should position itself below its anchor when position is bottom', fakeAsync( () => {
    const debugElement = fixture.debugElement;
    const windowService = debugElement.injector.get(WindowService);
    const documentService = debugElement.injector.get(DocumentService);
    const windowSpy = spyOn(windowService, 'nativeWindow').and.returnValue({pageYOffset: 0});
    const documentSpy = spyOn(documentService, 'nativeDocument')
      .and
      .returnValue({ documentElement: {scrollTop: 0}, body: {scrollTop: 0}});
    const container: any = fixture.debugElement.query(By.css('#testContainer'));
    container.triggerEventHandler('mouseenter', {});
    fixture.detectChanges();
    tick(100);
    const tooltip = fixture.debugElement.query(By.css('.ng-tooltip'));

    expect(container.nativeElement.offsetHeight).toBe(100);
    expect(tooltip.nativeElement.getBoundingClientRect().y).toEqual(165);
  }));
});
